This package contains the bSuite authenticator client for use with WSGI/ASGI backends. 
bSuite authentication implements a JWT/OAuth analogous flow with slight variations for security. 
Package provides the base authentication client which can either be used on its own with any backend,
or the drop-in FastAPI middleware can be used to add authentication in 2 lines. 
